@@ -1,8 +1,6 @@
-"""
-Created at 08.08.2019
-"""
+# pylint disable=fixme
+from pkg_resources import DistributionNotFound, VersionConflict, get_distribution
 
-from pkg_resources import get_distribution, DistributionNotFound, VersionConflict
 try:
     __version__ = get_distribution(__name__).version
 except (DistributionNotFound, VersionConflict):
