@@ -1,10 +1,11 @@
 import os
+import pathlib
 import re
 import sys
-import pathlib
+
 import pytest
-from ghapi.all import GhApi, paged
 from fastcore.net import ExceptionsHTTP
+from ghapi.all import GhApi, paged
 
 
 # https://stackoverflow.com/questions/7012921/recursive-grep-using-python
@@ -28,26 +29,30 @@ def grep(filepath, regex):
     return res
 
 
-@pytest.fixture(params=findfiles(
-    pathlib.Path(__file__).parent.parent.absolute(),
-    r'.*\.(ipynb|py|txt|yml|m|jl|md)$'
-))
+@pytest.fixture(
+    params=findfiles(
+        pathlib.Path(__file__).parent.parent.absolute(),
+        r".*\.(ipynb|py|txt|yml|m|jl|md)$",
+    )
+)
 def file(request):
     return request.param
 
 
-@pytest.fixture(scope='session')
+@pytest.fixture(scope="session")
 def gh_issues():
     res = {}
-    if 'CI' not in os.environ or ('GITHUB_ACTIONS' in os.environ and sys.version_info.minor >= 8):
+    if "CI" not in os.environ or (
+        "GITHUB_ACTIONS" in os.environ and sys.version_info.minor >= 8
+    ):
         try:
-            api = GhApi(owner='atmos-cloud-sim-uj', repo='PySDM')
+            api = GhApi(owner="atmos-cloud-sim-uj", repo="PySDM")
             pages = paged(
                 api.issues.list_for_repo,
-                owner='atmos-cloud-sim-uj',
-                repo='PySDM',
-                state='all',
-                per_page=100
+                owner="atmos-cloud-sim-uj",
+                repo="PySDM",
+                state="all",
+                per_page=100,
             )
             for page in pages:
                 for item in page.items:
@@ -60,13 +65,13 @@ def gh_issues():
 # pylint: disable=redefined-outer-name
 def test_todos_annotated(file, gh_issues):
     if (
-        os.path.basename(file) == 'test_todos_annotated.py' or
-        file.endswith("-checkpoint.ipynb") or
-        ".eggs" in file
+        os.path.basename(file) == "test_todos_annotated.py"
+        or file.endswith("-checkpoint.ipynb")
+        or ".eggs" in file
     ):
         return
-    for line in grep(file, r'.*TODO.*'):
-        match = re.search(r'TODO #(\d+)', line)
+    for line in grep(file, r".*TODO.*"):
+        match = re.search(r"TODO #(\d+)", line)
         if match is None:
             raise Exception(f"TODO not annotated with issue id ({line})")
         giving_up_with_hope_other_builds_did_it = len(gh_issues) == 0
@@ -74,5 +79,5 @@ def test_todos_annotated(file, gh_issues):
             number = int(match.group(1))
             if number not in gh_issues.keys():
                 raise Exception(f"TODO annotated with non-existent id ({line})")
-            if gh_issues[number] != 'open':
+            if gh_issues[number] != "open":
                 raise Exception(f"TODO remains for a non-open issue ({line})")
